@@ -10,7 +10,7 @@ use IO::File;
 use Pod::Tree::Node;
 use Pod::Tree::Stream;
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 sub new {
 	my $class = shift;
@@ -273,7 +273,7 @@ Pod::Tree - Create a static syntax tree for a POD
 
   use Pod::Tree;
   
-  $tree = new Pod::Tree;
+  $tree = Pod::Tree->new;
   $tree->load_file      ( $file, %options)
   $tree->load_fh        ( $fh  , %options);
   $tree->load_string    ( $pod , %options);
@@ -291,11 +291,6 @@ Pod::Tree - Create a static syntax tree for a POD
   print     $tree->dump;
 
 
-=head1 REQUIRES
-
-Pod::Escapes
-
-
 =head1 EXPORTS
 
 Nothing
@@ -312,7 +307,7 @@ See L<C<Pod::Tree::Node>> for a description of the tree.
 
 =over 4
 
-=item I<$tree> = C<new> C<Pod::Tree>
+=item I<$tree> = C<Pod::Tree>->C<new>
 
 Creates a new C<Pod::Tree> object.
 The syntax tree is initially empty.
